@@ -22,17 +22,18 @@ except Exception:
 
 
 logger = logging.getLogger(__name__)
-envvar = "PM_APP_ROOT"
-if envvar in os.environ:
-    PM_APP_ROOT = os.environ[envvar]
+PM_APP_ROOT = os.environ.get("PM_APP_ROOT", None)
+PM_SKIP_SETUP = os.environ.get("PM_SKIP_SETUP", False)
+if not PM_SKIP_SETUP and PM_APP_ROOT is None:
+    raise RuntimeError(
+        "Could not find environment variable PM_APP_ROOT. Please set the variable to set the path to the app root."
+    )
+
+if PM_APP_ROOT is not None and not PM_SKIP_SETUP:
     # Necessary for PMWS URL but also good for paths
     while PM_APP_ROOT[-1] == "/":
         PM_APP_ROOT = PM_APP_ROOT[:-1]
     _set_root(PM_APP_ROOT)
-elif "PM_SKIP_SETUP" not in os.environ:
-    raise RuntimeError(
-        "Could not find environment variable PM_APP_ROOT. Please set the variable to set the path to the app root."
-    )
 
 
 def describe_apps():
@@ -52,7 +53,7 @@ def describe_apps():
 
 protocols = None
 # Add the acellera-protocols folder as a submodule
-if "PM_SKIP_SETUP" not in os.environ:
+if not PM_SKIP_SETUP:
     root_dir = PM_APP_ROOT
     prot_dir = os.path.join(root_dir, "acellera-protocols")
 
