@@ -604,7 +604,11 @@ def slurm_mps(exec_dirs, **kwargs):
     for arg in kwargs:
         setattr(sl, arg, kwargs[arg])
 
-    sl.submit([ed.dirname for ed in exec_dirs], nvidia_mps=True)
+    sl.submit(
+        dirs=[ed.dirname for ed in exec_dirs],
+        runscripts=[ed.runsh for ed in exec_dirs],
+        nvidia_mps=True,
+    )
     return sl
 
 
@@ -663,7 +667,7 @@ def _write_inputs(write_dir, inputdir, arguments, manifest, function=None):
         ):
             newvals = []
             for val in vals:
-                if val is None:
+                if val is None or (isinstance(val, str) and val == ""):
                     continue
 
                 if isinstance(val, _File):
@@ -960,9 +964,8 @@ def __ensure_module_path(module_path):
     return sys.modules[full_path]
 
 
-def _manifest_to_func(appname, app_versions, latest):
+def _manifest_to_func(appname, app_versions):
     from copy import deepcopy
-    import sys
 
     for version in app_versions:
         manifest = app_versions[version]["manifest"]
@@ -1047,28 +1050,30 @@ def _manifest_to_func(appname, app_versions, latest):
                 logger.error(
                     f"Failed to parse manifest for app {appname} version {version} with error: {traceback.format_exc()}"
                 )
+    return func_names
 
-        # Link the latest version of the app to the top level module
-        parent_module = sys.modules[f"playmolecule.apps.{appname}"]
-        latest_module = sys.modules[f"playmolecule.apps.{appname}.{latest}"]
-        for symbol in func_names + [
-            "artifacts",
-            "datasets",
-            "files",
-            "tests",
-            "__manifest__",
-        ]:
-            if (
-                symbol not in parent_module.__dict__
-                and symbol in latest_module.__dict__
-            ):
-                setattr(
-                    sys.modules[f"playmolecule.apps.{appname}"],
-                    symbol,
-                    getattr(
-                        sys.modules.get(f"playmolecule.apps.{appname}.{latest}"), symbol
-                    ),
-                )
+
+def _link_latest_version(appname, latest, func_names):
+    import sys
+
+    # Link the latest version of the app to the top level module
+    parent_module = sys.modules[f"playmolecule.apps.{appname}"]
+    latest_module = sys.modules[f"playmolecule.apps.{appname}.{latest}"]
+    for symbol in func_names + [
+        "artifacts",
+        "datasets",
+        "files",
+        "tests",
+        "__manifest__",
+    ]:
+        if symbol not in parent_module.__dict__ and symbol in latest_module.__dict__:
+            setattr(
+                sys.modules[f"playmolecule.apps.{appname}"],
+                symbol,
+                getattr(
+                    sys.modules.get(f"playmolecule.apps.{appname}.{latest}"), symbol
+                ),
+            )
 
 
 def _check_folder_validity(root_dir, app_d):
@@ -1130,7 +1135,8 @@ def _set_root(root_dir):
                         f"Failed at parsing manifest JSON file {jf[0]} with error: {e}"
                     )
         if len(app_versions):
-            _manifest_to_func(appname, app_versions, vname)
+            func_names = _manifest_to_func(appname, app_versions)
+            _link_latest_version(appname, os.path.basename(versions[-1]), func_names)
 
     dsdir = os.path.join(root_dir, "datasets")
     dsjson = os.path.join(dsdir, "datasets.json")
