@@ -88,6 +88,10 @@ def _test_new_playmolecule_manifests():
     assert hasattr(apps.proteinpreparenew.v1, "files")
     assert hasattr(apps.proteinpreparenew.v1.proteinpreparenew, "tests")
     assert hasattr(apps.proteinpreparenew.v1.proteinpreparenew.tests, "simple")
+    assert hasattr(apps.proteinpreparenew.v2, "proteinpreparenew")
+    assert hasattr(apps.proteinpreparenew.v2, "files")
+    assert hasattr(apps.proteinpreparenew.v2.proteinpreparenew, "tests")
+    assert hasattr(apps.proteinpreparenew.v2.proteinpreparenew.tests, "simple")
     assert sorted(list(apps.proteinpreparenew.v1.files.keys())) == sorted(
         [
             "datasets",
